Set

Struct Set 

pub struct Set { /* private fields */ }
A set of JWT bundles for multiple trust domains.

Implementations

Source

impl Set

pub fn new(bundles: &[Bundle]) -> Set

Creates a new Set from the given bundles.

pub fn add(&self, bundle: &Bundle)

Adds a bundle to the set.

pub fn remove(&self, trust_domain: TrustDomain)

Removes the bundle for the given trust domain from the set.

pub fn has(&self, trust_domain: TrustDomain) -> bool

Returns true if the set has a bundle for the given trust domain.

pub fn get(&self, trust_domain: TrustDomain) -> Option<Bundle>

Returns the bundle for the given trust domain from the set.

pub fn bundles(&self) -> Vec<Bundle>

Returns all bundles in the set.

pub fn len(&self) -> usize

Returns the number of bundles in the set.

pub fn get_jwt_bundle_for_trust_domain( &self, trust_domain: TrustDomain, ) -> Result<Bundle>

Returns the JWT bundle for the given trust domain.