pub struct Bundle { /* private fields */ }Expand description
A JWT bundle contains the JWT authorities (public keys) for a trust domain.
Implementations
Sourceimpl Bundle
impl Bundle
Sourcepub fn new(trust_domain: TrustDomain) -> Bundle
pub fn new(trust_domain: TrustDomain) -> Bundle
Creates a new empty Bundle for the given trust domain.
Creates a new Bundle for the given trust domain and authorities.
Sourcepub fn load(trust_domain: TrustDomain, path: &str) -> Result<Bundle>
pub fn load(trust_domain: TrustDomain, path: &str) -> Result<Bundle>
Loads a JWT bundle from a JSON file (JWKS).
Sourcepub fn read(trust_domain: TrustDomain, reader: &mut dyn Read) -> Result<Bundle>
pub fn read(trust_domain: TrustDomain, reader: &mut dyn Read) -> Result<Bundle>
Reads a JWT bundle from a reader.
Sourcepub fn parse(trust_domain: TrustDomain, bytes: &[u8]) -> Result<Bundle>
pub fn parse(trust_domain: TrustDomain, bytes: &[u8]) -> Result<Bundle>
Parses a JWT bundle from JSON bytes (JWKS).
Sourcepub fn trust_domain(&self) -> TrustDomain
pub fn trust_domain(&self) -> TrustDomain
Returns the trust domain of the bundle.
Returns the JWT authorities in the bundle.
Finds a JWT authority by its key ID.
Returns true if the bundle has an authority with the given key ID.
Adds a JWT authority to the bundle.
Removes a JWT authority from the bundle.
Sets the JWT authorities in the bundle.
Sourcepub fn clone_bundle(&self) -> Bundle
pub fn clone_bundle(&self) -> Bundle
Clones the bundle.
Sourcepub fn equal(&self, other: &Bundle) -> bool
pub fn equal(&self, other: &Bundle) -> bool
Returns true if this bundle is equal to another bundle.
Sourcepub fn get_jwt_bundle_for_trust_domain(
&self,
trust_domain: TrustDomain,
) -> Result<Bundle>
pub fn get_jwt_bundle_for_trust_domain( &self, trust_domain: TrustDomain, ) -> Result<Bundle>
Returns the bundle for the given trust domain if it matches.