pub struct Set { /* private fields */ }Expand description
A set of JWT bundles for multiple trust domains.
Implementations
Sourceimpl Set
impl Set
Sourcepub fn remove(&self, trust_domain: TrustDomain)
pub fn remove(&self, trust_domain: TrustDomain)
Removes the bundle for the given trust domain from the set.
Sourcepub fn has(&self, trust_domain: TrustDomain) -> bool
pub fn has(&self, trust_domain: TrustDomain) -> bool
Returns true if the set has a bundle for the given trust domain.
Sourcepub fn get(&self, trust_domain: TrustDomain) -> Option<Bundle>
pub fn get(&self, trust_domain: TrustDomain) -> Option<Bundle>
Returns the bundle for the given trust domain from the set.
Sourcepub fn get_jwt_bundle_for_trust_domain(
&self,
trust_domain: TrustDomain,
) -> Result<Bundle>
pub fn get_jwt_bundle_for_trust_domain( &self, trust_domain: TrustDomain, ) -> Result<Bundle>
Returns the JWT bundle for the given trust domain.